### Name: project
### Title: Projects a sample.data object using the CONIFERS forest growth
###   model
### Aliases: project
### Keywords: models

### ** Examples

library( rconifers )

## set the variant to the SWO variant and set species map
set.species.map( set.variant(0) )

## grow the data SWO variant test data
# load and display CONIFERS example plots
data( plots.swo )
print( plots.swo )

# load and display CONIFERS example plants
data( plants.swo )
print( plants.swo )

# create the sample.data list object
sample.swo.3 <- list( plots=plots.swo, plants=plants.swo, age=3, x0=0.0 )
class(sample.swo.3)  <- "sample.data"

# now, project the sample forward for 20 years
# with all of the options turned off
sample.swo.23 <- project( sample.swo.3, 20,
          control=list(rand.err=0,rand.seed=0,endemic.mort=1,sdi.mort=1))

## print the projected summaries
print( sample.swo.23 )

# now, project the sample forward for 20 years
# with random error on and duplicate run 100 times, finish by calculating
#summaries of DF basal area
reps<-100
dfba<-vector(mode="double", length=reps)
for ( i in 1:reps){
sample.swo.23wr <- project( sample.swo.3, 20,
          control=list(rand.err=1,rand.seed=0,endemic.mort=1,sdi.mort=1))
          
#do a sp.sums of each run
summi<-sp.sums(sample.swo.23wr)

# select the Douglas-fir basal area
dfba[i]<-summi["DF","ba"]
}
summary(dfba)




